Learn R Programming

climatehealth (version 1.0.0)

air_pollution_meta_analysis: Perform meta analysis with multiple lag structures

Description

Implements distributed lag model. Individual lag coefficients and cumulative effects are extracted and perform meta analysis

Usage

air_pollution_meta_analysis(
  data_with_lags,
  max_lag = 14L,
  df_seasonal = 6L,
  family = "quasipoisson"
)

Value

Dataframe with lag-specific results including for regional and national

Arguments

data_with_lags

Lagged data

max_lag

Integer. Maximum lag days. Defaults to 14

df_seasonal

Integer. Degrees of freedom for seasonal spline. Default 6.

family

Character string indicating the distribution family used in the GAM.