Learn R Programming

climatehealth (version 1.0.0)

calculate_air_pollution_grid_dims: Generate a grid size for a certain number of plots.

Description

Generate a grid size for a certain number of plots.

Usage

calculate_air_pollution_grid_dims(n_plots)

Value

A list containing ncol and nrow values for the grid.

Arguments

n_plots

The number of plots required for the grid.