Learn R Programming

climatehealth (version 1.0.0)

calculate_qaic: QAIC calculation

Description

Computes the Quasi-Akaike Information Criterion (QAIC) for models, enabling model comparison

Usage

calculate_qaic(
  data,
  save_csv = FALSE,
  output_folder_path = NULL,
  print_results = FALSE
)

Value

Dataframe containing QAIC results for each lag.

Arguments

data

Dataframe containing a daily time series of climate and health data from which to fit models.

save_csv

Bool. Whether or not to save the VIF results to a CSV.

output_folder_path

String. Where to save the CSV file to (if save_csv == TRUE).

print_results

Logical. Whether or not to print model summaries and pearson dispersion statistics. Defaults to FALSE.