Learn R Programming

climatehealth (version 1.0.0)

check_diseases_vif: Check multicollinearity using VIF on model variables

Description

This function checks multicollinearity across the disease outcome, the exposure term(s) of interest, and the additional INLA covariates using a correlation-matrix-based variance inflation factor calculation.

Usage

check_diseases_vif(data, param_term, inla_param, case_type)

Value

A list with:

variables

Character vector of variables used in the VIF calculation.

vif

Numeric vector of VIF values aligned to variables.

vif_interpretation

Character vector of qualitative VIF interpretations ("Low", "Moderate", "High", or "Not computed").

Arguments

data

A data frame containing the disease outcome column, param_term, and the variables listed in inla_param.

param_term

Character vector of exposure variable term(s) to include in the VIF assessment.

inla_param

Character vector of additional model covariates to include in the VIF assessment.

case_type

Character. The type of disease that the case column refers to. Must be one of "diarrhea" or "malaria".