Learn R Programming

climatehealth (version 1.0.0)

combine_health_climate_data: Read in and combine climate and health data

Description

Read and combine climate and health data prepared for the spatiotemporal and DLNM analysis.

Usage

combine_health_climate_data(
  health_data_path,
  climate_data_path,
  map_path,
  region_col,
  district_col,
  date_col,
  year_col,
  month_col,
  case_col,
  case_type,
  tot_pop_col,
  tmin_col,
  tmean_col,
  tmax_col,
  rainfall_col,
  r_humidity_col,
  geometry_col,
  runoff_col = NULL,
  ndvi_col = NULL,
  spi_col = NULL,
  max_lag,
  output_dir = NULL
)

Value

A list of dataframes containing the map, nb.map, data, grid_data, summary

Arguments

health_data_path

The path to the health data.

climate_data_path

The path to the climate data.

map_path

The path to the relevant map data.

region_col

Character. Name of the column in the dataframe that contains the region names.

district_col

Character. Name of the column in the dataframe that contains the region names.

date_col

Character. Name of the column in the dataframe that contains the date. Defaults to NULL.

year_col

Character. Name of the column in the dataframe that contains the Year.

month_col

Character. Name of the column in the dataframe that contains the Month.

case_col

Character. Name of the column in the dataframe that contains the disease cases to be considered.

case_type

Character. The type of disease that the case column refers to. Must be one of 'diarrhea' or 'malaria'.

tot_pop_col

Character. Name of the column in the dataframe that contains the total population.

tmin_col

Character. Name of the column in the dataframe that contains the minimum temperature data.

tmean_col

Character. Name of the column in the dataframe that contains the average temperature.

tmax_col

Character. Name of the column in the dataframe that contains the maximum temperature.

rainfall_col

Character. Name of the column in the dataframe that contains the cumulative monthly rainfall.

r_humidity_col

Character. Name of the column in the dataframe that contains the relative humidity.

geometry_col

is the Name of the geometry column in the shapefile (usually "geometry").

runoff_col

Character. Name of the column in the dataframe that contains the monthly runoff water data. Defaults to NULL.

ndvi_col

Character. Name of column containing the Normalized Difference Vegetation Index (ndvi) data. Defaults to NULL.

spi_col

Character. Name of the column in the dataframe that contains the standardized precipitation index. Defaults to NULL.

max_lag

Character. Number corresponding to the maximum lag to be considered for the delay effect. It should be between 2 an 4. Defaults to 2.

output_dir

Path to folder where the processed map data should be saved. Defaults to NULL.