Learn R Programming

climatehealth (version 1.0.0)

common_descriptive_stats: Deprecated alias for run_descriptive_stats().

Description

Generic wrapper function to compute descriptive statistics and EDA outputs.

Usage

common_descriptive_stats(
  df_list,
  output_path,
  aggregation_column = NULL,
  population_col = NULL,
  plot_corr_matrix = FALSE,
  correlation_method = "pearson",
  plot_dist = FALSE,
  plot_ma = FALSE,
  ma_days = 100,
  ma_sides = 1,
  timeseries_col = NULL,
  dependent_col,
  independent_cols,
  units = NULL,
  plot_na_counts = FALSE,
  plot_scatter = FALSE,
  plot_box = FALSE,
  plot_seasonal = FALSE,
  plot_regional = FALSE,
  plot_total = FALSE,
  detect_outliers = FALSE,
  calculate_rate = FALSE
)

Value

Character vector. Backward-compatible output path format.

Deprecated. Use run_descriptive_stats() instead.

Arguments

df_list

List of dataframes. A list of input dataframes.

output_path

Character. The path to write outputs to.

aggregation_column

Character. The column to use for aggregating the dataset into smaller subsets of regions.

population_col

Character. The column containing the population.

plot_corr_matrix

Logical. Whether or not to plot correlation matrix.

correlation_method

Character. The correlation method. One of 'pearson', 'spearman', 'kendall'.

plot_dist

Logical. Whether or not to plot distribution histograms.

plot_ma

Logical. Whether to plot moving averages over a timeseries.

ma_days

Integer. The number of days to use for a moving average.

ma_sides

Integer. The number of sides to use for a moving average (1 or 2).

timeseries_col

Character. The column used as the timeseries for moving averages.

dependent_col

Character. The column in the data containing the dependent variable.

independent_cols

Character vector. The columns in the data containing the independent variables.

units

Named character vector. A named character vector of units for each variable.

plot_na_counts

Logical. Whether to plot NA counts.

plot_scatter

Logical. Whether to plot scatter plots.

plot_box

Logical. Whether to plot box plots.

plot_seasonal

Logical. Whether to plot seasonal plots.

plot_regional

Logical. Whether to plot regional plots.

plot_total

Logical. Whether to plot total health outcomes per year.

detect_outliers

Logical. Whether to output a table containing outlier information.

calculate_rate

Logical. Whether to calculate the rate of health outcomes per 100k people.