Learn R Programming

climatehealth (version 1.0.0)

common_descriptive_stats_api: Deprecated alias for run_descriptive_stats_api().

Description

Deprecated alias for run_descriptive_stats_api().

Usage

common_descriptive_stats_api(
  data,
  aggregation_column = NULL,
  population_col = NULL,
  dependent_col,
  independent_cols,
  units = NULL,
  plot_correlation = FALSE,
  plot_dist_hists = FALSE,
  plot_ma = FALSE,
  plot_na_counts = FALSE,
  plot_scatter = FALSE,
  plot_box = FALSE,
  plot_seasonal = FALSE,
  plot_regional = FALSE,
  plot_total = FALSE,
  correlation_method = "pearson",
  ma_days = 100,
  ma_sides = 1,
  timeseries_col = NULL,
  detect_outliers = FALSE,
  calculate_rate = FALSE,
  output_path
)

Value

Character vector. Backward-compatible output path format.

Deprecated. Use run_descriptive_stats_api() instead.

Arguments

data

The dataset used for descriptive stats (as a vector).

aggregation_column

Character. The column to use for aggregating the dataset into smaller subsets.

population_col

Character. The column containing the population.

dependent_col

Character. The dependent column.

independent_cols

Character vector. The independent columns.

units

Named character vector. A named character vector of units for each variable.

plot_correlation

Logical. Whether to plot a correlation matrix.

plot_dist_hists

Logical. Whether to plot histograms showing column distributions.

plot_ma

Logical. Whether to plot moving averages over a timeseries.

plot_na_counts

Logical. Whether to plot counts of NAs in each column.

plot_scatter

Logical. Whether to plot the dependent column against the independent columns.

plot_box

Logical. Whether to generate box plots for selected columns.

plot_seasonal

Logical. Whether to plot seasonal trends of the variables in columns.

plot_regional

Logical. Whether to plot regional trends of the variables in columns.

plot_total

Logical. Whether to plot the total of the dependent column per year.

correlation_method

Character. The correlation method. One of 'pearson', 'spearman', 'kendall'.

ma_days

Integer. The number of days to use in moving average calculations.

ma_sides

Integer. The number of sides to use in moving average calculations (1 or 2).

timeseries_col

Character. The column used as the timeseries for moving averages.

detect_outliers

Logical. Whether to have a table of outliers.

calculate_rate

Logical. Whether to plot a rate based metric of the dependent column per year.

output_path

Character. The path to save outputs to.