Learn R Programming

climatehealth (version 1.0.0)

contour_plot: Create and plot the exposure-lag-response relationship (contour plot) at country, region or district level for each disease cases type (diarrhea and malaria).

Description

: Generates a contour plot showing the exposure-lag-response relationship of the exposure tmax and rainfall and the diseases case type.

Usage

contour_plot(
  data,
  param_term,
  model,
  level,
  max_lag,
  nk,
  case_type,
  filter_year = NULL,
  save_fig = FALSE,
  output_dir = NULL
)

Value

contour plot at country, Region and District level

Arguments

data

Data list from combine_health_climate_data() function.

param_term

A character vector or list containing parameter terms such as tmax (temperature exposure) and rainfall(rainfall exposure). Default to tmax.

model

The fitted model from the run_inla_models() function.

level

A character vector specifying the geographical disaggregation. Can take one of the following values: "country", "region", or "district".

case_type

Character. The type of disease that the case column refers to. Must be one of diarrhea or malaria.

filter_year

Integer. The year to filter to data to. Defaults to NULL.

save_fig

Boolean. Whether to save the outputted plot. Defaults to FALSE.

output_dir

The path to save the visualisation to. Defaults to NULL