Create a correlation matrix for columns in a dataframe.
create_correlation_matrix(
df,
independent_cols = NULL,
correlation_method = "pearson"
)Matrix. Correlation matrix for selected columns in the input dataset.
Dataframe. The dataframe to use to create a correlation matrix.
Character vector. The columns in the data containing the independent variables.
string. The method to use for correlation calculations.