Learn R Programming

climatehealth (version 1.0.0)

create_grid: Generate a grid size for a certain number of plots.

Description

This function calculates the minimum grid size required to plot X amount of plots on a a figure. For example, 6 plots would require a 3x2, where as 7 would require a 3x3, and so on.

Usage

create_grid(plot_count)

Value

A numeric vector: c(x, y), where x and y define the grid dimensions.

Arguments

plot_count

The number of plots required for the grid.