Learn R Programming

climatehealth (version 1.0.0)

create_temperature_splines: Generate splines for temperature variable

Description

Generates temperature splines for each region

Usage

create_temperature_splines(data, nlag = 0, degrees_freedom = 6)

Value

Dataframe with additional column for temperature spline.

Arguments

data

Dataframe containing a daily time series of climate and health data

nlag

Integer. The number of days of lag in the temperature variable from which to generate splines (unlagged temperature variable). Defaults to 0.

degrees_freedom

Integer. Degrees of freedom for the spline(s). Defaults to 6.