Learn R Programming

climatehealth (version 1.0.0)

deprecate_descriptive_stats: Emit a consistent deprecation warning for descriptive stats wrappers.

Description

Emit a consistent deprecation warning for descriptive stats wrappers.

Usage

deprecate_descriptive_stats(old_fn, new_fn)

Value

None. Emits a warning.

Arguments

old_fn

Character. Deprecated function name.

new_fn

Character. Replacement function name.