Learn R Programming

climatehealth (version 1.0.0)

descriptive_stats_core: Core Functionality for Producing Descriptive Statistics

Description

Core Functionality for Producing Descriptive Statistics

Usage

descriptive_stats_core(
  df,
  output_path,
  title,
  aggregation_column = NULL,
  population_col = NULL,
  plot_corr_matrix = FALSE,
  correlation_method = "pearson",
  plot_dist = FALSE,
  dependent_col,
  independent_cols = c(),
  units = NULL,
  plot_na_counts = FALSE,
  plot_scatter = FALSE,
  plot_box = FALSE,
  plot_seasonal = FALSE,
  plot_regional = FALSE,
  plot_total = FALSE,
  timeseries_col = "date",
  write_outlier_table = FALSE,
  calculate_rate = FALSE
)

Value

None. Outputs are written to files.

Arguments

df

Dataframe. The input DataFrame.

output_path

Character. The path to write outputs to.

title

Character. The specific title for the subset of data being used.

aggregation_column

Character. Column to aggregate data by.

population_col

Character. Column containing population data.

plot_corr_matrix

Logical. Whether or not to plot correlation matrix.

correlation_method

Character. The correlation method. One of 'pearson', 'spearman', 'kendall'.

plot_dist

Logical. Whether or not to plot distribution histograms.

dependent_col

Character. The dependent column.

independent_cols

Character vector. The independent columns.

units

Named character vector. Units to use for plots (maps to columns parameter).

plot_na_counts

Logical. Whether to plot NA counts.

plot_scatter

Logical. Whether to plot scatter plots.

plot_box

Logical. Whether to plot box plots.

plot_seasonal

Logical. Whether to plot seasonal plots.

plot_regional

Logical. Whether to plot regional plots.

plot_total

Logical. Whether to plot total health outcomes per year.

timeseries_col

Character. Column containing timeseries data (e.g., date).

write_outlier_table

Logical. Whether to output a table containing outlier information.

calculate_rate

Logical. Whether to calculate the rate of health outcomes per 100k people.