Learn R Programming

climatehealth (version 1.0.0)

dlnm_pop_totals: Create population totals

Description

Creates a list of population totals by year and region for use in the attributable rate calculations.

Usage

dlnm_pop_totals(df_list, country = "National", meta_analysis = FALSE)

Value

List of population totals by year and region

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.

country

Character. Name of country for national level estimates. Defaults to 'National'

meta_analysis

Boolean. Whether to perform a meta-analysis. Defaults to FALSE.