Learn R Programming

climatehealth (version 1.0.0)

dlnm_power_list: Power calculation

Description

Produce a power statistic by area for the attributable threshold and above as a reference.

Usage

dlnm_power_list(
  df_list,
  pred_list,
  minperc,
  attr_thr_high = 97.5,
  attr_thr_low = 2.5,
  compute_low = TRUE
)

Value

A list containing power information by area.

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.

pred_list

A list containing predictions from the model by region.

minperc

Vector. Percentile of maximum outcome temperature for each region.

attr_thr_high

Integer. Percentile at which to define the upper temperature threshold for calculating attributable risk. Defaults to 97.5.

attr_thr_low

Integer. Percentile at which to define the lower temperature threshold for calculating attributable risk. Defaults to 2.5.

compute_low

Bool. Whether to computer power for the lower threshold. Defaults to FALSE