Learn R Programming

climatehealth (version 1.0.0)

dlnm_predict_nat: Run national predictions from meta analysis

Description

Use the meta analysis to create national level predictions

Usage

dlnm_predict_nat(
  df_list,
  var_fun = "bs",
  var_per = c(25, 50, 75),
  var_degree = 2,
  minpercreg,
  mmpredall,
  pred_list,
  country = "National"
)

Value

A list containing predictions by region.

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.

var_fun

Character. Exposure function for argvar (see dlnm::crossbasis). Defaults to 'bs'.

var_per

Vector. Internal knot positions for argvar (see dlnm::crossbasis). Defaults to c(25, 50, 75).

var_degree

Integer. Degree of the piecewise polynomial for argvar (see dlnm::crossbasis). Defaults to 2 (quadratic).

minpercreg

Vector. Percentile of maximum suicide temperature for each region.

mmpredall

List of national coefficients and covariance matrices for the crosspred.

pred_list

A list containing predictions from the model by region.

country

Character. Name of country for national level estimates. Defaults to National.