Learn R Programming

climatehealth (version 1.0.0)

dlnm_reduce_cumulative: Reduce to overall cumulative

Description

Reduce model to the overall cumulative association

Usage

dlnm_reduce_cumulative(
  df_list,
  var_per = c(25, 50, 75),
  var_degree = 2,
  cenper = NULL,
  cb_list,
  model_list
)

Value

  • coef_ A matrix of coefficients for the reduced model.

  • vcov_ A list. Covariance matrices for each region for the reduced model.

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.

var_per

Vector. Internal knot positions for argvar (see dlnm::crossbasis). Defaults to c(25, 50, 75).

var_degree

Integer. Degree of the piecewise polynomial for argvar (see dlnm::crossbasis). Defaults to 2 (quadratic).

cenper

Integer. Value for the percentile in calculating the centering value 0-100. Defaults to NULL.

cb_list

List of cross_basis matrices from create_crossbasis function.

model_list

List of models produced from DLNM analysis.