Learn R Programming

climatehealth (version 1.0.0)

get_predictions: A function to predict relative risk at country, region, and district level

Description

Produces cumulative relative risk at country, region and district level from analysis.

Usage

get_predictions(data, param_term, max_lag, nk, model, level, case_type)

Value

A dataframe containing cumulative relative risk at the chosen level.

Arguments

data

Data list from combine_health_climate_data() function.

param_term

A character vector or list containing parameter terms such as tmax (maximum temperature) and rainfall (rainfall exposure).

model

The fitted model from run_inla_models() function.

level

Character. The spatial disaggregation level. Can take one of the following values: country, region, or district.

case_type

Character. The type of disease that the case column refers to. Must be one of diarrhea or malaria.