Learn R Programming

climatehealth (version 1.0.0)

hc_attr: Estimate attributable numbers

Description

Estimate attributable numbers and confidence intervals for each geography using Monte Carlo simulations.

Usage

hc_attr(
  df_list,
  cb_list,
  pred_list,
  minpercgeog_,
  attr_thr_high = 97.5,
  attr_thr_low = 2.5
)

Value

'attr_list'. A list containing attributable numbers per geography.

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.

cb_list

A list of cross-basis matrices by geography.

pred_list

A list containing predictions from the model by geography.

minpercgeog_

Vector. Percentile of minimum mortality temperature for each geography.

attr_thr_high

Integer. Percentile at which to define the upper temperature threshold for calculating attributable risk. Defaults to 97.5.

attr_thr_low

Integer. Percentile at which to define the lower temperature threshold for calculating attributable risk. Defaults to 2.5.