Learn R Programming

climatehealth (version 1.0.0)

hc_attr_tables: Create attributable estimates tables

Description

Aggregate tables of attributable numbers, rates and fractions for total, yearly and monthly by geography and national level.

Usage

hc_attr_tables(attr_list, country = "National", meta_analysis = FALSE)

Value

  • res_attr_tot Dataframe. Total attributable fractions, numbers and rates for each geography over the whole time series.

  • attr_yr_list List. Dataframes containing yearly estimates of attributable fractions, numbers and rates by geography.

  • attr_mth_list List. Dataframes containing total attributable fractions, numbers and rates by calendar month and geography.

Arguments

attr_list

A list containing attributable numbers per geography.

country

Character. Name of country for national level estimates. Defaults to 'National'.

meta_analysis

Boolean. Whether to perform a meta-analysis. Defaults to FALSE.