Learn R Programming

climatehealth (version 1.0.0)

hc_model_combo_res: Produce check results of model combinations

Description

Runs every combination of model based on user selected additional independent variables and returns model diagnostic checks for each.

Usage

hc_model_combo_res(df_list, cb_list, independent_cols = NULL, dfseas = 8)

Value

  • qaic_results A dataframe of QAIC and dispersion metrics for each model combination.

  • residuals_list List. Residuals for each model combination.

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.

cb_list

List of cross-basis matrices from hc_create_crossbasis function.

independent_cols

Character/list. Additional independent variables to test in model validation as confounders. Defaults to NULL.

dfseas

Integer. Degrees of freedom for seasonality. Defaults to 8.