Learn R Programming

climatehealth (version 1.0.0)

hc_plot_ar_cold_yearly: Plot attributable rates by year - low temperatures

Description

Plot attributable rates by year and geography with confidence intervals.

Usage

hc_plot_ar_cold_yearly(
  attr_yr_list,
  save_fig = FALSE,
  output_folder_path = NULL,
  country = "National"
)

Value

Plots of yearly attributable rates per geography.

Arguments

attr_yr_list

A list of matrices containing yearly estimates of attributable fractions, numbers and rates by geography.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

output_folder_path

Path to folder where plots should be saved. Defaults to NULL.

country

Character. Name of country for national level estimates. Defaults to 'National'.