Learn R Programming

climatehealth (version 1.0.0)

hc_plot_ar_heat_monthly: Plot attributable rates by calendar month - high temperatures

Description

Plot attributable rates grouped over the whole time series by calendar month to explore seasonality.

Usage

hc_plot_ar_heat_monthly(
  attr_mth_list,
  df_list,
  country = "National",
  attr_thr_high = 97.5,
  save_fig = FALSE,
  output_folder_path = NULL
)

Value

Plots of attributable rates by calendar month per geography.

Arguments

attr_mth_list

A list of data frames containing total attributable fractions, numbers and rates by calendar month and geography.

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.

country

Character. Name of country for national level estimates. Defaults to 'National'.

attr_thr_high

Integer. Percentile at which to define the upper temperature threshold for calculating attributable risk. Defaults to 97.5.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

output_folder_path

Path to folder where plots should be saved. Defaults to NULL.