Plot attributable rates by year and geography with confidence intervals.
hc_plot_ar_heat_yearly(
attr_yr_list,
save_fig = FALSE,
output_folder_path = NULL,
country = "National"
)Plots of yearly attributable rates per geography.
A list of matrices containing yearly estimates of attributable fractions, numbers and rates by geography.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Path to folder where plots should be saved. Defaults to NULL.
Character. Name of country for national level estimates. Defaults to 'National'.