Learn R Programming

climatehealth (version 1.0.0)

hc_plot_attr_cold_totals: Plot total attributable fractions and rates - low temperatures

Description

Plot total attributable fractions and rates over the whole time series by geography.

Usage

hc_plot_attr_cold_totals(
  df_list,
  res_attr_tot,
  save_fig = FALSE,
  output_folder_path = NULL,
  country = "National"
)

Value

Plots of total attributable fractions and rates by geography

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.

res_attr_tot

Matrix containing total attributable fractions, numbers and rates for each geography over the whole time series.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

output_folder_path

Path to folder where plots should be saved. Defaults to NULL.

country

Character. Name of country for national level estimates. Defaults to 'National'.