Plot total attributable fractions and rates over the whole time series by geography.
hc_plot_attr_heat_totals(
df_list,
res_attr_tot,
save_fig = FALSE,
output_folder_path = NULL,
country = "National"
)Plots of total attributable fractions and rates by geography.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.
Matrix containing total attributable fractions, numbers and rates for each geography over the whole time series.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Path to folder where plots should be saved. Defaults to NULL.
Character. Name of country for national level estimates. Defaults to 'National'.