Learn R Programming

climatehealth (version 1.0.0)

hc_plot_power: Plot statistical power for temperature mortality analysis

Description

Plots the power statistic for each reference temperature at and above the attributable risk threshold for each geography.

Usage

hc_plot_power(
  power_list_high,
  power_list_low,
  save_fig = FALSE,
  output_folder_path = NULL,
  country = "National"
)

Value

Plots of power by temperature for the attributable thresholds and above for each geography.

Arguments

power_list_high

List. A list containing power information for high temperatures by geography.

power_list_low

List. A list containing power information for low temperatures by geography.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

output_folder_path

Character. Path to folder where plots should be saved. Defaults to NULL.

country

Character. The name of the country for national level estimates. Defaults to 'National'.