Learn R Programming

climatehealth (version 1.0.0)

hc_plot_rr: Plot results of relative risk analysis

Description

Plots cumulative lag exposure-response function with histogram of temperature distribution for each geography.

Usage

hc_plot_rr(
  df_list,
  pred_list,
  attr_thr_high = 97.5,
  attr_thr_low = 2.5,
  minpercgeog_,
  country = "National",
  save_fig = FALSE,
  output_folder_path = NULL
)

Value

Plots of cumulative lag exposure-response function with histogram of temperature distribution for each geography.

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.

pred_list

A list containing predictions from the model by geography.

attr_thr_high

Integer. Percentile at which to define the upper temperature threshold for calculating attributable risk. Defaults to 97.5.

attr_thr_low

Integer. Percentile at which to define the lower temperature threshold for calculating attributable risk. Defaults to 2.5.

minpercgeog_

Vector. Percentile of minimum mortality temperature for each geography.

country

Character. Name of country for national level estimates. Defaults to 'National'.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

output_folder_path

Path to folder where plots should be saved. Defaults to NULL.