Learn R Programming

climatehealth (version 1.0.0)

hc_predict_subnat: Run predictions from model

Description

Use model to run predictions. Predictions can be produced for a single input geography, or multiple disaggregated geographies.

Usage

hc_predict_subnat(
  df_list,
  var_fun = "bs",
  var_per = c(10, 75, 90),
  var_degree = 2,
  mintempgeog_,
  blup,
  coef_,
  vcov_,
  meta_analysis = FALSE
)

Value

'pred_list'. A list containing predictions by geography.

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.

var_fun

Character. Exposure function for argvar (see dlnm::crossbasis). Defaults to 'bs'.

var_per

Vector. Internal knot positions for argvar (see dlnm::crossbasis). Defaults to c(10, 75, 90).

var_degree

Integer. Degree of the piecewise polynomial for argvar (see dlnm::crossbasis). Defaults to 2 (quadratic).

mintempgeog_

Vector. Percentile of minimum mortality temperature for each geography.

blup

A list. BLUP (best linear unbiased predictions) from the meta-analysis model for each geography.

coef_

A matrix of coefficients for the reduced model.

vcov_

A list. Covariance matrices for each geography for the reduced model.

meta_analysis

Boolean. Whether to perform a meta-analysis. Defaults to FALSE.