Learn R Programming

climatehealth (version 1.0.0)

hc_quasipoisson_dlnm: Define and run quasi-Poisson regression with DLNM

Description

Fits a quasi-Poisson case-crossover with a distributed lag non-linear model.

Usage

hc_quasipoisson_dlnm(df_list, control_cols = NULL, cb_list, dfseas = 8)

Value

'model_list'. List containing models by geography.

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.

control_cols

List. Confounders to include in the final model adjustment. Defaults to NULL.

cb_list

List of cross-basis matrices from hc_create_crossbasis function.

dfseas

Integer. Degrees of freedom for seasonality. Defaults to 8.