Learn R Programming

climatehealth (version 1.0.0)

hc_read_data: Read temperature-related mortality indicator data

Description

Reads in data and geography names for analysis from a CSV file.

Usage

hc_read_data(
  input_csv_path,
  dependent_col,
  date_col,
  region_col,
  temperature_col,
  population_col
)

Value

'df_list'. A list of dataframes for each geography with formatted and renamed columns.

Arguments

input_csv_path

Path to a CSV containing a daily time series of health outcome and climate data per geography.

dependent_col

Character. Name of the column in the dataframe containing the dependent health outcome variable e.g. deaths.

date_col

Character. Name of the column in the dataframe containing the date.

region_col

Character. Name of the column in the dataframe that contains the geography name(s).

temperature_col

Character. Name of the column in the dataframe that contains the temperature column.

population_col

Character. Name of the column in the dataframe that contains the population estimate per geography.