Learn R Programming

climatehealth (version 1.0.0)

hc_rr_results: Produce cumulative relative risk results of analysis

Description

Produces cumulative relative risk and confidence intervals from analysis.

Usage

hc_rr_results(
  pred_list,
  df_list,
  minpercgeog_,
  attr_thr_high = 97.5,
  attr_thr_low = 2.5
)

Value

'rr_results'. Dataframe containing cumulative relative risk and confidence intervals from analysis.

Arguments

pred_list

A list containing predictions from the model by geography.

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.

minpercgeog_

Vector. Percentile of minimum mortality temperature for each geography.

attr_thr_high

Integer. Percentile at which to define the upper temperature threshold for calculating attributable risk. Defaults to 97.5.

attr_thr_low

Integer. Percentile at which to define the lower temperature threshold for calculating attributable risk. Defaults to 2.5.