Learn R Programming

climatehealth (version 1.0.0)

hc_save_results: Save results of analysis

Description

Saves a CSV file of cumulative relative risk and confidence intervals.

Usage

hc_save_results(
  rr_results,
  res_attr_tot,
  attr_yr_list,
  attr_mth_list,
  power_list_high,
  power_list_low,
  output_folder_path = NULL
)

Arguments

rr_results

Dataframe containing cumulative relative risk and confidence intervals from analysis.

res_attr_tot

Matrix containing total attributable fractions, numbers and rates for each geography over the whole time series.

attr_yr_list

A list of matrices containing yearly estimates of attributable fractions, numbers and rates by geography.

attr_mth_list

A list of data frames containing total attributable fractions, numbers and rates by calendar month and geography.

output_folder_path

Path to folder where results should be saved. Defaults to NULL.