Learn R Programming

climatehealth (version 1.0.0)

join_health_and_climate_data: Join health and climate data

Description

Joins a daily time series of wildfire PM2.5 data with a daily time series of health data.

Usage

join_health_and_climate_data(
  climate_data,
  health_data,
  region_col = "region",
  date_col = "date",
  exposure_col = "mean_PM"
)

Value

Dataframe containing a daily time series of the joined climate and health data.

Arguments

climate_data

Character. Dataframe containing a daily time series of climate data, which may be disaggregated by region.

health_data

Character. Path to a CSV file containing a daily time series of data for a particular health outcome, which may be disaggregated by region.

region_col

Character. Name of the region column in both datasets. Defaults to 'region'

date_col

Character. Name of the date column in both datasets. Defaults to 'date'

exposure_col

Character. Name of the column in the climate data containing the exposure column (e.g., PM2.5) in kilograms. Defaults to 'mean_PM'.