Learn R Programming

climatehealth (version 1.0.0)

mh_attr: Estimate attributable numbers

Description

Estimate attributable numbers for each region and confidence intervals using Monte Carlo simulations.

Usage

mh_attr(df_list, cb_list, pred_list, minpercreg, attr_thr = 97.5)

Value

A list containing attributable numbers per region

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.

cb_list

A list of cross-basis matrices by region.

pred_list

A list containing predictions from the model by region.

minpercreg

Vector. Percentile of maximum suicide temperature for each region.

attr_thr

Integer. Percentile at which to define the temperature threshold for calculating attributable risk. Defaults to 97.5.