Learn R Programming

climatehealth (version 1.0.0)

mh_attr_tables: Create attributable estimates tables

Description

Aggregate tables of attributable numbers, rates and fractions for total, yearly and monthly by region and nation

Usage

mh_attr_tables(attr_list, country = "National", meta_analysis = FALSE)

Value

  • res_attr_tot Dataframe. Total attributable fractions, numbers and rates for each area over the whole time series.

  • attr_yr_list List. Dataframes containing yearly estimates of attributable fractions, numbers and rates by area.

  • attr_mth_list List. Dataframes containing total attributable fractions, numbers and rates by calendar month and area.

Arguments

attr_list

A list containing attributable numbers per region.

country

Character. Name of country for national level estimates. Defaults to 'National'.

meta_analysis

Boolean. Whether to perform a meta-analysis. Defaults to FALSE.