Runs every combination of model based on user selected additional independent variables and returns model diagnostic checks for each.
mh_model_combo_res(df_list, cb_list, independent_cols = NULL)qaic_results A dataframe of QAIC and dispersion metrics for each model
combination.
residuals_list A list. Residuals for each model combination.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
List of cross_basis matrices from create_crossbasis function.
Additional independent variables to test in model validation as confounders.