Learn R Programming

climatehealth (version 1.0.0)

mh_model_validation: Model Validation Assessment

Description

Produces results on QAIC for each model combination, variance inflation factor for each independent variable, and plots for residuals to assess the models

Usage

mh_model_validation(
  df_list,
  cb_list,
  independent_cols = NULL,
  save_fig = FALSE,
  save_csv = FALSE,
  output_folder_path = NULL,
  seed = NULL
)

Value

  • qaic_results A dataframe of QAIC and dispersion metrics for each model combination and geography.

  • qaic_summary A dataframe with the mean QAIC and dispersion metrics for each model combination.

  • vif_results A dataframe. Variance inflation factors for each independent variables by region.

  • vif_summary A dataframe with the mean variance inflation factors for each independent variable.

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.

cb_list

List of cross_basis matrices from create_crossbasis function.

independent_cols

Additional independent variables to test in model validation as confounders.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

save_csv

Boolean. Whether to save the results as a CSV. Defaults to FALSE.

output_folder_path

Path to folder where plots should be saved. Defaults to NULL.