Learn R Programming

climatehealth (version 1.0.0)

mh_plot_af_monthly: Plot attributable fractions by calendar month

Description

Plot attributable fractions grouped over the whole time series by calendar month to explore seasonality.

Usage

mh_plot_af_monthly(
  attr_mth_list,
  df_list,
  country = "National",
  attr_thr = 97.5,
  save_fig = FALSE,
  output_folder_path = NULL
)

Value

Plots of attributable fractions by calendar month per area

Arguments

attr_mth_list

A list of data frames containing total attributable fractions, numbers and rates by calendar month and area.

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.

country

Character. Name of country for national level estimates. Defaults to 'National'.

attr_thr

Integer. Percentile at which to define the temperature threshold for calculating attributable risk. Defaults to 97.5.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

output_folder_path

Path to folder where plots should be saved. Defaults to NULL.