Plot attributable rates grouped over the whole time series by calendar month to explore seasonality.
mh_plot_ar_monthly(
attr_mth_list,
df_list,
country = "National",
attr_thr = 97.5,
save_fig = FALSE,
output_folder_path = NULL
)Plots of attributable rates by calendar month per area
A list of data frames containing total attributable fractions, numbers and rates by calendar month and area.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
Character. Name of country for national level estimates. Defaults to 'National'.
Integer. Percentile at which to define the temperature threshold for calculating attributable risk. Defaults to 97.5.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Path to folder where plots should be saved. Defaults to NULL.