Plot total attributable fractions and rates over the whole time series by area.
mh_plot_attr_totals(
df_list,
res_attr_tot,
save_fig = FALSE,
output_folder_path = NULL,
country = "National"
)Plots of total attributable fractions and rates by area
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
Matrix containing total attributable fractions, numbers and rates for each area over the whole time series.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Path to folder where plots should be saved. Defaults to NULL.
Character. Name of country for national level estimates. Defaults to 'National'.