Learn R Programming

climatehealth (version 1.0.0)

mh_plot_power: Plot power

Description

Plots the power statistic for each reference temperature at and above the attributable risk threshold for each area.

Usage

mh_plot_power(
  power_list,
  save_fig = FALSE,
  output_folder_path = NULL,
  country = "National"
)

Value

Plots of power by temperature for the attributable threshold and above for each area.

Arguments

power_list

A list containing power information by area.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

output_folder_path

Path to folder where plots should be saved. Defaults to NULL.

country

Character. Name of country for national level estimates. Defaults to 'National'