Learn R Programming

climatehealth (version 1.0.0)

mh_plot_rr: Plot results of relative risk analysis - Mental Health

Description

Plots cumulative lag exposure-response function with histogram of temperature distribution for each region

Usage

mh_plot_rr(
  df_list,
  pred_list,
  attr_thr = 97.5,
  minpercreg,
  country = "National",
  save_fig = FALSE,
  output_folder_path = NULL
)

Value

Plots of cumulative lag exposure-response function with histogram of temperature distribution for each region

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.

pred_list

A list containing predictions from the model by region.

attr_thr

Integer. Percentile at which to define the temperature threshold for calculating attributable risk. Defaults to 97.5.

minpercreg

Vector. Percentile of minimum suicide temperature for each area.

country

Character. Name of country for national level estimates. Defaults to 'National'.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

output_folder_path

Path to folder where plots should be saved. Defaults to NULL.