Learn R Programming

climatehealth (version 1.0.0)

mh_predict_reg: Run regional predictions from model

Description

Use model to run regional predictions

Usage

mh_predict_reg(
  df_list,
  var_fun = "bs",
  var_per = c(25, 50, 75),
  var_degree = 2,
  minpercreg,
  blup,
  coef_,
  vcov_,
  meta_analysis = FALSE
)

Value

A list containing predictions by region

Arguments

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.

var_fun

Character. Exposure function for argvar (see dlnm::crossbasis). Defaults to 'bs'.

var_per

Vector. Internal knot positions for argvar (see dlnm::crossbasis). Defaults to c(25,50,75).

var_degree

Integer. Degree of the piecewise polynomial for argvar (see dlnm::crossbasis). Defaults to 2 (quadratic).

minpercreg

Vector. Percentile of maximum suicide temperature for each region.

blup

A list. BLUP (best linear unbiased predictions) from the meta-analysis model for each region.

coef_

A matrix of coefficients for the reduced model.

vcov_

A list. Covariance matrices for each region for the reduced model.

meta_analysis

Boolean. Whether to perform a meta-analysis.