Learn R Programming

climatehealth (version 1.0.0)

mh_rr_results: Produce cumulative relative risk results of analysis

Description

Produces cumulative relative risk and confidence intervals from analysis.

Usage

mh_rr_results(pred_list, df_list, attr_thr = 97.5, minpercreg)

Value

Dataframe containing cumulative relative risk and confidence intervals from analysis.

Arguments

pred_list

A list containing predictions from the model by region.

df_list

A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.

attr_thr

Integer. Percentile at which to define the temperature threshold for calculating attributable risk. Defaults to 97.5.

minpercreg

Vector. Percentile of minimum suicide temperature for each area.