Plots relative risk and confidence intervals for each lag value of wildfire-related PM2.5
plot_RR(
rr_data,
wildfire_lag,
by_region = FALSE,
save_fig = FALSE,
output_folder_path = NULL
)Plot of relative risk and confidence intervals for each lag of wildfire-related PM2.5
Dataframe of relative risk and confidence intervals for each lag of wildfire-related PM2.5
Integer. The maximum number of days for which to plot the lags for wildfire PM2.5. Defaults to 3.
Bool. Whether to plot RR(relative risk) by region. Defaults to FALSE
Boolean. Whether to save the generated plot. Defaults to FALSE.
Path to folder where plots should be saved.