Learn R Programming

climatehealth (version 1.0.0)

plot_RR_core: Core functionality for plotting results of relative risk analysis.

Description

Plots relative risk and confidence intervals for each lag value of wildfire-related PM2.5.

Usage

plot_RR_core(
  rr_data,
  save_fig = FALSE,
  wildfire_lag,
  output_folder_path = NULL,
  region_name = "All regions",
  ylims = NULL
)

Value

Plot of relative risk and confidence intervals for each lag of wildfire-related PM2.5.

Arguments

rr_data

Dataframe of relative risk and confidence intervals for each lag of wildfire-related PM2.5.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

wildfire_lag

Integer. The maximum number of days for which to plot the lags for wildfire PM2.5. Defaults to 3.

output_folder_path

Path to folder where plots should be saved. Defaults to NULL.

region_name

Character. The name of the region. Defaults to 'All regions'.