Learn R Programming

climatehealth (version 1.0.0)

plot_aggregated_AF_core: Create a plot of aggregated annual attributable fractions with CI

Description

Aggregates annual average attributable fraction estimates and generates a ggplot showing the central estimate and CI.

Usage

plot_aggregated_AF_core(data, region_name = NULL)

Value

A ggplot object showing annual attributable rates with confidence intervals.

Arguments

data

A data frame with columns: year, average_attributable_fraction, lower_ci_attributable_fraction, and upper_ci_attributable_fraction.

region_name

Optional character string used to label the plot title with a region name. Defaults to NULL.