Learn R Programming

climatehealth (version 1.0.0)

plot_an_by_region: Plot Total Attributable Number by Region

Description

Aggregates wildfire smoke-related PM2.5 attributable numbers by region and creates a bar plot showing the total attributable number of deaths per region.

Usage

plot_an_by_region(data, output_dir = ".")

Value

A ggplot object representing the bar plot.

Arguments

data

A data frame containing columns:

  • region: Region names.

  • total_attributable_number: Numeric values of attributable numbers.

output_dir

A character string specifying the directory where the plot will be saved. Defaults to the current working directory (".").