Learn R Programming

climatehealth (version 1.0.0)

plot_ar_by_region: Plot Attributable Risk by Region

Description

Aggregates wildfire-specific PM2.5 attributable risk (deaths per 100k) by region and creates a bar plot showing the mean attributable risk per region.

Usage

plot_ar_by_region(data, output_dir = ".")

Value

A ggplot object representing the bar plot.

Arguments

data

A data frame containing columns:

  • region: Region names.

  • deaths_per_100k: Numeric values of deaths per 100k population.

  • lower_ci_deaths_per_100k: Lower bound of confidence interval.

  • upper_ci_deaths_per_100k: Upper bound of confidence interval.

output_dir

A character string specifying the directory where the plot will be saved. Defaults to the current working directory (".").