Learn R Programming

climatehealth (version 1.0.0)

plot_monthly_random_effects: Visualise monthly random effects for selected INLA model

Description

Generates and saves a plot of monthly random effects for different regions, visualizing their contribution to Malaria Incidence Rate.

Usage

plot_monthly_random_effects(
  combined_data,
  model,
  save_fig = FALSE,
  output_dir = NULL
)

Value

THe monthly random effects plot.

Arguments

combined_data

Data list from combine_health_climate_data() function.

model

The fitted model object.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

output_dir

Character. The path to save the visualisation to. Defaults to NULL.