Learn R Programming

climatehealth (version 1.0.0)

plot_rate_overall: Plot the rate of a dependent variable per 100,000 population per year.

Description

Plot the rate of a dependent variable per 100,000 population per year.

Usage

plot_rate_overall(
  df,
  dependent_col,
  population_col,
  date_col,
  title,
  save_rate = FALSE,
  output_path = NULL
)

Arguments

df

The dataframe containing the data.

dependent_col

The name of the column representing the dependent variable.

population_col

The name of the column representing the population.

date_col

The name of the column containing date values.

title

Character. The specific title for the subset of data being used.

save_rate

Whether to save the plot as a PDF.

output_path

The file path to save the plot if save_rate is TRUE.