Learn R Programming

climatehealth (version 1.0.0)

plot_rr_map: Plot Relative Risk Map at sub-national Level

Description

Generates a map of the relative risk of the diseases cases associated with climate hazards, including extreme temperature and cumulative rainfall, at a specified geographical level (district or region).

Usage

plot_rr_map(
  combined_data,
  model,
  param_term = "tmax",
  max_lag,
  nk,
  level = "district",
  case_type,
  filter_year = NULL,
  output_dir = NULL,
  save_fig = FALSE,
  save_csv = FALSE,
  cumulative = FALSE
)

Value

Relative risk map at the chosen level.

Arguments

combined_data

A list returned from the combine_health_climate_data() function. This list should include both the health-climate data and the map data.

model

The fitted model object returned from the run_inla_models() function.

param_term

A character vector or list specifying the climate parameters (e.g., tmax for maximum temperature, rainfall for precipitation) to include in the map. Defaults to tmax.

level

A character string indicating the spatial aggregation level. Options are region or district. Defaults to district.

case_type

Character. The type of disease that the case column refers to. Must be one of diarrhea or malaria.

filter_year

Integer. The year to filter to data to. Defaults to NULL.

output_dir

Character. The directory path where the output PDF file should be saved. Defaults to NULL.

save_fig

Boolean. If TRUE, saves the plot to the specified directory. Defaults to FALSE.

cumulative

Boolean. If TRUE, plot and save cumulative risk of all year for the specific exposure at region and district level. Defaults to FALSE.