Learn R Programming

climatehealth (version 1.0.0)

plot_scatter_grid: Plot a grid of scatter graphs comparing one column to various others.

Description

Plot a grid of scatter graphs comparing one column to various others.

Usage

plot_scatter_grid(
  df,
  main_col,
  comparison_cols,
  title,
  save_scatters = FALSE,
  output_path = "",
  units = NULL
)

Arguments

df

The dataframe containing the raw data.

main_col

The main column to compare with all other columns.

comparison_cols

The columns to compare with.

title

The title of your plot.

save_scatters

Whether or not to save the plot.

output_path

The path to output the plot to.

units

A named character vector of units for each variable.