Learn R Programming

climatehealth (version 1.0.0)

plot_seasonal_trends: Plot seasonal trends of a health outcome and climate by month.

Description

Plot seasonal trends of a health outcome and climate by month.

Usage

plot_seasonal_trends(
  df,
  date_col,
  outcome_cols,
  title = "Seasonal Averages",
  ylabs = NULL,
  save_plot = FALSE,
  output_path = ""
)

Arguments

df

The dataframe containing the raw data.

date_col

The name of the column containing date values.

outcome_cols

Character Vector. The names of the outcome columns to analyse.

title

The title of your plot.

ylabs

A character vector of y-axis labels (e.g., with units) corresponding to the columns.

save_plot

Whether or not to save the plot.

output_path

The path to output the plot to.