Learn R Programming

climatehealth (version 1.0.0)

plot_total_variables_by_year: Plot the total of selected variables per year.

Description

Plot the total of selected variables per year.

Usage

plot_total_variables_by_year(
  df,
  date_col,
  variables,
  title,
  save_total = FALSE,
  output_path = ""
)

Value

Plots are printed to the console or saved as PDF files.

Arguments

df

A dataframe containing the data.

date_col

The name of the column containing date values.

variables

Column names to be summed and plotted.

title

Character. The specific title for the subset of data being used.

save_total

if TRUE, saves each plot as a PDF.

output_path

The file path for saving plots.