Learn R Programming

climatehealth (version 1.0.0)

plot_yearly_spatial_random_effect: Visualize yearly spatial random effect of the Diseases Incidence Rate (DIR).

Description

Generates and saves plots of yearly spatial random effect of the diseases incidence rate at district level.

Usage

plot_yearly_spatial_random_effect(
  combined_data,
  model,
  case_type,
  save_fig = FALSE,
  output_dir = NULL
)

Value

The yearly space random effect for the disease incidence rate plot.

Arguments

combined_data

Data list from combine_health_climate_data() function.

model

The fitted model from run_inla_models() function.

case_type

Character. The type of disease that the case column refers to. Must be one of diarrhea or malaria.

save_fig

Boolean. Whether to save the plot as an output. Defaults to FALSE.

output_dir

Character. The path to save the fitted model results to. Defaults to NULL.