Learn R Programming

climatehealth (version 1.0.0)

read_input_data: Read a csv file into memory as a data frame.

Description

Read a csv file into memory as a data frame.

Usage

read_input_data(input_csv_path)

Value

A dataframe containing the data from the csv.

Arguments

input_csv_path

The path to the csv to read as a dataframe.

Examples

Run this code
input_csv_path <- "directory/file_name.csv"

Run the code above in your browser using DataLab