Learn R Programming

climatehealth (version 1.0.0)

save_wildfire_results: Save results of wildfire related analysis

Description

Saves a CSV file of relative risk and confidence intervals for each lag value of wildfire-related PM2.5. Also optionally save results of attributable numbers/fractions.

Usage

save_wildfire_results(
  rr_results,
  an_ar_results = NULL,
  annual_af_an_results = NULL,
  output_folder_path
)

Arguments

rr_results

Dataframe of relative risk and confidence intervals for each lag of wildfire-related PM2.5.

an_ar_results

Dataframe containing attributable number/fraction results. Defaults to NULL.

output_folder_path

Path to folder where results should be saved.