Learn R Programming

climatehealth (version 1.0.0)

summarise_AF_AN: Summarise AF and AN numbers by region and year

Description

Takes daily data with attributable fraction and attributable number and summarises by year and region.

Usage

summarise_AF_AN(data, monthly = TRUE)

Value

Dataframe containing summarised AF and AN data, by year, region and optionall month (if monthly == TRUE).

Arguments

data

Dataframe containing daily data including calculated AF and AN.

monthly

Bool. Whether to summarise by month as well as year and region. Defaults to TRUE.