Learn R Programming

climatehealth (version 1.0.0)

time_stratify: Stratify data by time period

Description

Adds columns for strata for each region:year:month:dayofweek and for the total counts of a health outcome across days in each stratum.

Usage

time_stratify(data)

Value

Dataframe with additional columns for stratum (region:year:month:dayofweek) and for the total counts of a health outcome across days in each stratum.

Arguments

data

Dataframe containing a daily time series of climate and health data. Assumes that 'data' has a 'month', 'year', 'dow' and 'region' column.