Learn R Programming

climatehealth (version 1.0.0)

validate_descriptive_columns: Preflight validation for descriptive statistics columns based on enabled features.

Description

Preflight validation for descriptive statistics columns based on enabled features.

Usage

validate_descriptive_columns(
  df,
  context = "dataset",
  dependent_col,
  independent_cols,
  aggregation_column = NULL,
  population_col = NULL,
  timeseries_col = NULL,
  plot_corr_matrix = FALSE,
  plot_dist = FALSE,
  plot_ma = FALSE,
  plot_scatter = FALSE,
  plot_box = FALSE,
  plot_seasonal = FALSE,
  plot_regional = FALSE,
  plot_total = FALSE,
  write_outlier_table = FALSE,
  calculate_rate = FALSE,
  is_full_dataset = FALSE
)

Value

None. Stops execution if required columns/params are missing.

Arguments

df

Dataframe. Dataset to validate.

context

Character. Context label for error messages.

dependent_col

Character. Dependent column.

independent_cols

Character vector. Independent columns.

aggregation_column

Character. Region aggregation column.

population_col

Character. Population column.

timeseries_col

Character. Timeseries column.

plot_corr_matrix

Logical. Correlation matrix toggle.

plot_dist

Logical. Distribution plot toggle.

plot_ma

Logical. Moving average toggle.

plot_scatter

Logical. Scatter plot toggle.

plot_box

Logical. Boxplot toggle.

plot_seasonal

Logical. Seasonal plot toggle.

plot_regional

Logical. Regional plot toggle.

plot_total

Logical. Total-by-year plot toggle.

write_outlier_table

Logical. Outlier table toggle.

calculate_rate

Logical. Rate plot toggle.

is_full_dataset

Logical. Whether this dataset is the full combined dataset.