Implements distributed lag model. Individual lag coefficients and cumulative effects are extracted and perform meta analysis
air_pollution_meta_analysis(
data_with_lags,
max_lag = 14L,
df_seasonal = 6L,
family = "quasipoisson"
)Dataframe with lag-specific results including for regional and national
Lagged data
Integer. Maximum lag days. Defaults to 14
Integer. Degrees of freedom for seasonal spline. Default 6.
Character string indicating the distribution family used in the GAM.