Takes a calculated RR and upper and lower CIs, and applies these to the input data to calculate attributable fraction and attributable number, along with upper and lower CIs, for each day in the input data. Uses Lag 1 RR and lower/upper CIs.
calculate_daily_AF_AN(data, rr_data)A dataframe containing a daily timseries of AF and AN, including upper and lower confidence intervals.
Dataframe containing a daily time series of climate and health data that was used to obtain rr_data.
Dataframe containing relative risk and confidence intervals, calculated from input data.