Computes the Quasi-Akaike Information Criterion (QAIC) for models, enabling model comparison
calculate_qaic(
data,
save_csv = FALSE,
output_folder_path = NULL,
print_results = FALSE
)Dataframe containing QAIC results for each lag.
Dataframe containing a daily time series of climate and health data from which to fit models.
Bool. Whether or not to save the VIF results to a CSV.
String. Where to save the CSV file to (if save_csv == TRUE).
Logical. Whether or not to print model summaries and pearson dispersion statistics. Defaults to FALSE.