This function checks multicollinearity across the disease outcome, the exposure term(s) of interest, and the additional INLA covariates using a correlation-matrix-based variance inflation factor calculation.
check_diseases_vif(data, param_term, inla_param, case_type)A list with:
Character vector of variables used in the VIF calculation.
Numeric vector of VIF values aligned to variables.
Character vector of qualitative VIF interpretations
("Low", "Moderate", "High", or "Not computed").
A data frame containing the disease outcome column, param_term,
and the variables listed in inla_param.
Character vector of exposure variable term(s) to include in the VIF assessment.
Character vector of additional model covariates to include in the VIF assessment.
Character. The type of disease that the case column refers
to. Must be one of "diarrhea" or "malaria".