check_file_exists: Check that a file exists at a passed path.
Description
Checks the files on disk to assert that the passed file is
present.
Usage
check_file_exists(fpath, raise = TRUE)
Value
'exists'. Whether or not the file exists on disk.
Arguments
- fpath
The filepath to check exists.
- raise
Whether or not to raise an error if the file does not exist,
Default: TRUE