Read and combine climate and health data prepared for the spatiotemporal and DLNM analysis.
combine_health_climate_data(
health_data_path,
climate_data_path,
map_path,
region_col,
district_col,
date_col,
year_col,
month_col,
case_col,
case_type,
tot_pop_col,
tmin_col,
tmean_col,
tmax_col,
rainfall_col,
r_humidity_col,
geometry_col,
runoff_col = NULL,
ndvi_col = NULL,
spi_col = NULL,
max_lag,
output_dir = NULL
)A list of dataframes containing the map, nb.map, data, grid_data, summary
The path to the health data.
The path to the climate data.
The path to the relevant map data.
Character. Name of the column in the dataframe that contains the region names.
Character. Name of the column in the dataframe that contains the region names.
Character. Name of the column in the dataframe that contains the date. Defaults to NULL.
Character. Name of the column in the dataframe that contains the Year.
Character. Name of the column in the dataframe that contains the Month.
Character. Name of the column in the dataframe that contains the disease cases to be considered.
Character. The type of disease that the case column refers to. Must be one of 'diarrhea' or 'malaria'.
Character. Name of the column in the dataframe that contains the total population.
Character. Name of the column in the dataframe that contains the minimum temperature data.
Character. Name of the column in the dataframe that contains the average temperature.
Character. Name of the column in the dataframe that contains the maximum temperature.
Character. Name of the column in the dataframe that contains the cumulative monthly rainfall.
Character. Name of the column in the dataframe that contains the relative humidity.
is the Name of the geometry column in the shapefile (usually "geometry").
Character. Name of the column in the dataframe that contains the monthly runoff water data. Defaults to NULL.
Character. Name of column containing the Normalized Difference Vegetation Index (ndvi) data. Defaults to NULL.
Character. Name of the column in the dataframe that contains the standardized precipitation index. Defaults to NULL.
Character. Number corresponding to the maximum lag to be considered for the delay effect. It should be between 2 an 4. Defaults to 2.
Path to folder where the processed map data should be saved. Defaults to NULL.