run_descriptive_stats().Generic wrapper function to compute descriptive statistics and EDA outputs.
common_descriptive_stats(
df_list,
output_path,
aggregation_column = NULL,
population_col = NULL,
plot_corr_matrix = FALSE,
correlation_method = "pearson",
plot_dist = FALSE,
plot_ma = FALSE,
ma_days = 100,
ma_sides = 1,
timeseries_col = NULL,
dependent_col,
independent_cols,
units = NULL,
plot_na_counts = FALSE,
plot_scatter = FALSE,
plot_box = FALSE,
plot_seasonal = FALSE,
plot_regional = FALSE,
plot_total = FALSE,
detect_outliers = FALSE,
calculate_rate = FALSE
)Character vector. Backward-compatible output path format.
Deprecated. Use run_descriptive_stats() instead.
List of dataframes. A list of input dataframes.
Character. The path to write outputs to.
Character. The column to use for aggregating the dataset into smaller subsets of regions.
Character. The column containing the population.
Logical. Whether or not to plot correlation matrix.
Character. The correlation method. One of 'pearson', 'spearman', 'kendall'.
Logical. Whether or not to plot distribution histograms.
Logical. Whether to plot moving averages over a timeseries.
Integer. The number of days to use for a moving average.
Integer. The number of sides to use for a moving average (1 or 2).
Character. The column used as the timeseries for moving averages.
Character. The column in the data containing the dependent variable.
Character vector. The columns in the data containing the independent variables.
Named character vector. A named character vector of units for each variable.
Logical. Whether to plot NA counts.
Logical. Whether to plot scatter plots.
Logical. Whether to plot box plots.
Logical. Whether to plot seasonal plots.
Logical. Whether to plot regional plots.
Logical. Whether to plot total health outcomes per year.
Logical. Whether to output a table containing outlier information.
Logical. Whether to calculate the rate of health outcomes per 100k people.