run_descriptive_stats_api().Deprecated alias for run_descriptive_stats_api().
common_descriptive_stats_api(
data,
aggregation_column = NULL,
population_col = NULL,
dependent_col,
independent_cols,
units = NULL,
plot_correlation = FALSE,
plot_dist_hists = FALSE,
plot_ma = FALSE,
plot_na_counts = FALSE,
plot_scatter = FALSE,
plot_box = FALSE,
plot_seasonal = FALSE,
plot_regional = FALSE,
plot_total = FALSE,
correlation_method = "pearson",
ma_days = 100,
ma_sides = 1,
timeseries_col = NULL,
detect_outliers = FALSE,
calculate_rate = FALSE,
output_path
)Character vector. Backward-compatible output path format.
Deprecated. Use run_descriptive_stats_api() instead.
The dataset used for descriptive stats (as a vector).
Character. The column to use for aggregating the dataset into smaller subsets.
Character. The column containing the population.
Character. The dependent column.
Character vector. The independent columns.
Named character vector. A named character vector of units for each variable.
Logical. Whether to plot a correlation matrix.
Logical. Whether to plot histograms showing column distributions.
Logical. Whether to plot moving averages over a timeseries.
Logical. Whether to plot counts of NAs in each column.
Logical. Whether to plot the dependent column against the independent columns.
Logical. Whether to generate box plots for selected columns.
Logical. Whether to plot seasonal trends of the variables in columns.
Logical. Whether to plot regional trends of the variables in columns.
Logical. Whether to plot the total of the dependent column per year.
Character. The correlation method. One of 'pearson', 'spearman', 'kendall'.
Integer. The number of days to use in moving average calculations.
Integer. The number of sides to use in moving average calculations (1 or 2).
Character. The column used as the timeseries for moving averages.
Logical. Whether to have a table of outliers.
Logical. Whether to plot a rate based metric of the dependent column per year.
Character. The path to save outputs to.