diarrhea and malaria).: Generates a contour plot showing the exposure-lag-response
relationship of the exposure tmax and rainfall and the diseases case type.
contour_plot(
data,
param_term,
model,
level,
max_lag,
nk,
case_type,
filter_year = NULL,
save_fig = FALSE,
output_dir = NULL
)contour plot at country, Region and District level
Data list from combine_health_climate_data() function.
A character vector or list containing parameter terms such
as tmax (temperature exposure) and rainfall(rainfall exposure).
Default to tmax.
The fitted model from the run_inla_models() function.
A character vector specifying the geographical disaggregation. Can take one of the following values: "country", "region", or "district".
Character. The type of disease that the case column refers
to. Must be one of diarrhea or malaria.
Integer. The year to filter to data to. Defaults to NULL.
Boolean. Whether to save the outputted plot. Defaults to FALSE.
The path to save the visualisation to. Defaults to NULL