: For the INLA model, there is a need to set-up regions index, district index, and year index. This function create these indices using the dataset, ndistrict and nregion.
create_inla_indices(data, case_type)The modified data with the created indices.
is the dataframe containing district_code, region_code, and year columns from the combine_health_climate_data() function.
Character. The type of disease that the case column refers to. Must be one of 'diarrhea' or 'malaria'.