Generates temperature splines for each region
create_temperature_splines(data, nlag = 0, degrees_freedom = 6)Dataframe with additional column for temperature spline.
Dataframe containing a daily time series of climate and health data
Integer. The number of days of lag in the temperature variable from which to generate splines (unlagged temperature variable). Defaults to 0.
Integer. Degrees of freedom for the spline(s). Defaults to 6.