Generates summary statistics for climate and health data and saves them to the specified file path.
descriptive_stats(data, variables, bin_width = 5, output_dir = ".")Prints summary statistics and a histogram of the the outcome variable
Dataframe containing a daily time series of climate and health data
Character or character vector with variable to produce summary statistics for. Must include at least 1 variable.
Integer. Width of each bin in a histogram of the outcome variable. Defaults to 5.
Character. The directory to output descriptive stats to. Must exist and will not be automatically created. Defaults to ".".