Core Functionality for Producing Descriptive Statistics
descriptive_stats_core(
df,
output_path,
title,
aggregation_column = NULL,
population_col = NULL,
plot_corr_matrix = FALSE,
correlation_method = "pearson",
plot_dist = FALSE,
dependent_col,
independent_cols = c(),
units = NULL,
plot_na_counts = FALSE,
plot_scatter = FALSE,
plot_box = FALSE,
plot_seasonal = FALSE,
plot_regional = FALSE,
plot_total = FALSE,
timeseries_col = "date",
write_outlier_table = FALSE,
calculate_rate = FALSE
)None. Outputs are written to files.
Dataframe. The input DataFrame.
Character. The path to write outputs to.
Character. The specific title for the subset of data being used.
Character. Column to aggregate data by.
Character. Column containing population data.
Logical. Whether or not to plot correlation matrix.
Character. The correlation method. One of 'pearson', 'spearman', 'kendall'.
Logical. Whether or not to plot distribution histograms.
Character. The dependent column.
Character vector. The independent columns.
Named character vector. Units to use for plots (maps to columns parameter).
Logical. Whether to plot NA counts.
Logical. Whether to plot scatter plots.
Logical. Whether to plot box plots.
Logical. Whether to plot seasonal plots.
Logical. Whether to plot regional plots.
Logical. Whether to plot total health outcomes per year.
Character. Column containing timeseries data (e.g., date).
Logical. Whether to output a table containing outlier information.
Logical. Whether to calculate the rate of health outcomes per 100k people.