detect_outliers: Detect Outliers Using the IQR Method
Description
Detect Outliers Using the IQR Method
Usage
detect_outliers(df, independent_cols = NULL)
Value
Dataframe. Column summaries
Arguments
- df
A data frame containing the data to check for outliers.
- independent_cols
Character vector. The columns in the data containing the independent variables.