Run meta-analysis using temperature average and range as meta predictors. Then create the best linear unbiased predictions (BLUPs).
dlnm_meta_analysis(
df_list,
coef_,
vcov_,
save_csv = FALSE,
output_folder_path = NULL
)mm A model object. A multivariate meta-analysis model.
blup A list. BLUP (best linear unbiased predictions) from the
meta-analysis model for each region.
meta_test_res A dataframe of results from statistical tests on the meta model.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
A matrix of coefficients for the reduced model.
A list. Covariance matrices for each region for the reduced model.
Boolean. Whether to save the results as a CSV. Defaults to FALSE.
Path to folder where results should be saved. Defaults to NULL.