Calculate the temperature at which there is minimum mortality risk using the product of the basis matrix and BLUPs.
dlnm_min_mortality_temp(
df_list,
var_fun = "bs",
var_per = c(10, 75, 90),
var_degree = 2,
blup = NULL,
coef_,
meta_analysis = FALSE,
outcome_type = c("temperature", "suicide")
)Percentiles and corresponding temperatures for each geography.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
Character. Exposure function for argvar (see dlnm::crossbasis). Defaults to 'bs'.
Vector. Internal knot positions for argvar (see dlnm::crossbasis). Defaults to c(10, 75, 90).
Integer. Degree of the piecewise polynomial for argvar (see dlnm::crossbasis). Defaults to 2 (quadratic).
A list. BLUP (best linear unbiased predictions) from the meta-analysis model for each region. Defaults to NULL.
A matrix of coefficients for the reduced model.
Boolean. Whether to perform a meta-analysis. Defaults to FALSE.
Character. The indicator that the function is being used for. One of 'suicide' or 'temperature'. Defaults to c("temperature", "suicide")