Creates a list of population totals by year and region for use in the attributable rate calculations.
dlnm_pop_totals(df_list, country = "National", meta_analysis = FALSE)List of population totals by year and region
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
Character. Name of country for national level estimates. Defaults to 'National'
Boolean. Whether to perform a meta-analysis. Defaults to FALSE.