Use the meta analysis to create national level predictions
dlnm_predict_nat(
df_list,
var_fun = "bs",
var_per = c(25, 50, 75),
var_degree = 2,
minpercreg,
mmpredall,
pred_list,
country = "National"
)A list containing predictions by region.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
Character. Exposure function for argvar (see dlnm::crossbasis). Defaults to 'bs'.
Vector. Internal knot positions for argvar (see dlnm::crossbasis). Defaults to c(25, 50, 75).
Integer. Degree of the piecewise polynomial for argvar (see dlnm::crossbasis). Defaults to 2 (quadratic).
Vector. Percentile of maximum suicide temperature for each region.
List of national coefficients and covariance matrices for the crosspred.
A list containing predictions from the model by region.
Character. Name of country for national level estimates. Defaults to National.