Reduce model to the overall cumulative association
dlnm_reduce_cumulative(
df_list,
var_per = c(25, 50, 75),
var_degree = 2,
cenper = NULL,
cb_list,
model_list
)coef_ A matrix of coefficients for the reduced model.
vcov_ A list. Covariance matrices for each region for the reduced model.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
Vector. Internal knot positions for argvar (see dlnm::crossbasis). Defaults to c(25, 50, 75).
Integer. Degree of the piecewise polynomial for argvar (see dlnm::crossbasis). Defaults to 2 (quadratic).
Integer. Value for the percentile in calculating the centering value 0-100. Defaults to NULL.
List of cross_basis matrices from create_crossbasis function.
List of models produced from DLNM analysis.