get_alpha_colour: Generate and RGB colour value with alpha from a hex value.
Description
Generate and RGB colour value with alpha from a hex value.
Usage
get_alpha_colour(hex, alpha)
Value
The converted RGB colour.
Arguments
- hex
The hex code of the colour to convert.
- alpha
The alpha of the converted colour (ranging from 0-1).