Produces cumulative relative risk at country, region and district level from analysis.
get_predictions(data, param_term, max_lag, nk, model, level, case_type)A dataframe containing cumulative relative risk at the chosen level.
Data list from combine_health_climate_data() function.
A character vector or list containing parameter terms such
as tmax (maximum temperature) and rainfall (rainfall exposure).
The fitted model from run_inla_models() function.
Character. The spatial disaggregation level.
Can take one of the following values: country, region, or district.
Character. The type of disease that the case column refers
to. Must be one of diarrhea or malaria.