Aggregate to national data and run crossbasis
hc_add_national_data(
df_list,
pop_list,
var_fun = "bs",
var_per = c(10, 75, 90),
var_degree = 2,
lagn = 21,
lagnk = 3,
country = "National",
cb_list,
mm,
minpercgeog_
)df_list List. A list of data frames for each geography and
national level.
cb_list List. A list of cross-basis matrices by geography and
national level.
minpercgeog_ Vector. Percentile of minimum mortality temperature
for each geography and national level.
mmpredall List. A list of national coefficients and covariance
matrices.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.
List of population totals by year and geography.
Character. Exposure function for argvar (see dlnm::crossbasis). Defaults to 'bs'.
Vector. Internal knot positions for argvar (see dlnm::crossbasis). Defaults to c(10, 75, 90).
Integer. Degree of the piecewise polynomial for argvar (see dlnm::crossbasis). Defaults to 2 (quadratic).
Integer. Number of days in the lag period. Defaults to 21. (see dlnm::crossbasis).
Integer. Number of knots in lag function. Defaults to 3. (see dlnm::logknots).
Character. Name of country for national level estimates. Defaults to 'National'.
A list of cross-basis matrices by geography.
A model object. A multivariate meta-analysis model.
Vector. Percentile of minimum mortality temperature for each geography.