hc_adf: Run ADF test and produce PACF plots for each model combination
Description
Run augmented Dickey-Fuller test for stationarity of dependent
variable and produce a partial autocorrelation function plot of residuals
for each model combination.
Usage
hc_adf(df_list)
Value
'adf_list'. List of ADF results for each geography.
Arguments
df_list
A list of dataframes containing daily timeseries data for a
health outcome and climate variables which may be disaggregated by a
particular geography.