Estimate attributable numbers and confidence intervals for each geography using Monte Carlo simulations.
hc_attr(
df_list,
cb_list,
pred_list,
minpercgeog_,
attr_thr_high = 97.5,
attr_thr_low = 2.5
)'attr_list'. A list containing attributable numbers per geography.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.
A list of cross-basis matrices by geography.
A list containing predictions from the model by geography.
Vector. Percentile of minimum mortality temperature for each geography.
Integer. Percentile at which to define the upper temperature threshold for calculating attributable risk. Defaults to 97.5.
Integer. Percentile at which to define the lower temperature threshold for calculating attributable risk. Defaults to 2.5.