Runs every combination of model based on user selected additional independent variables and returns model diagnostic checks for each.
hc_model_combo_res(df_list, cb_list, independent_cols = NULL, dfseas = 8)qaic_results A dataframe of QAIC and dispersion metrics for each
model combination.
residuals_list List. Residuals for each model combination.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.
List of cross-basis matrices from hc_create_crossbasis function.
Character/list. Additional independent variables to test in model validation as confounders. Defaults to NULL.
Integer. Degrees of freedom for seasonality. Defaults to 8.