Plots the power statistic for each reference temperature at and above the attributable risk threshold for each geography.
hc_plot_power(
power_list_high,
power_list_low,
save_fig = FALSE,
output_folder_path = NULL,
country = "National"
)Plots of power by temperature for the attributable thresholds and above for each geography.
List. A list containing power information for high temperatures by geography.
List. A list containing power information for low temperatures by geography.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Character. Path to folder where plots should be saved. Defaults to NULL.
Character. The name of the country for national level estimates. Defaults to 'National'.