Plots cumulative lag exposure-response function with histogram of temperature distribution for each geography.
hc_plot_rr(
df_list,
pred_list,
attr_thr_high = 97.5,
attr_thr_low = 2.5,
minpercgeog_,
country = "National",
save_fig = FALSE,
output_folder_path = NULL
)Plots of cumulative lag exposure-response function with histogram of temperature distribution for each geography.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.
A list containing predictions from the model by geography.
Integer. Percentile at which to define the upper temperature threshold for calculating attributable risk. Defaults to 97.5.
Integer. Percentile at which to define the lower temperature threshold for calculating attributable risk. Defaults to 2.5.
Vector. Percentile of minimum mortality temperature for each geography.
Character. Name of country for national level estimates. Defaults to 'National'.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Path to folder where plots should be saved. Defaults to NULL.