Use model to run predictions. Predictions can be produced for a single input geography, or multiple disaggregated geographies.
hc_predict_subnat(
df_list,
var_fun = "bs",
var_per = c(10, 75, 90),
var_degree = 2,
mintempgeog_,
blup,
coef_,
vcov_,
meta_analysis = FALSE
)'pred_list'. A list containing predictions by geography.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.
Character. Exposure function for argvar (see dlnm::crossbasis). Defaults to 'bs'.
Vector. Internal knot positions for argvar (see dlnm::crossbasis). Defaults to c(10, 75, 90).
Integer. Degree of the piecewise polynomial for argvar (see dlnm::crossbasis). Defaults to 2 (quadratic).
Vector. Percentile of minimum mortality temperature for each geography.
A list. BLUP (best linear unbiased predictions) from the meta-analysis model for each geography.
A matrix of coefficients for the reduced model.
A list. Covariance matrices for each geography for the reduced model.
Boolean. Whether to perform a meta-analysis. Defaults to FALSE.