Fits a quasi-Poisson case-crossover with a distributed lag non-linear model.
hc_quasipoisson_dlnm(df_list, control_cols = NULL, cb_list, dfseas = 8)'model_list'. List containing models by geography.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.
List. Confounders to include in the final model adjustment. Defaults to NULL.
List of cross-basis matrices from hc_create_crossbasis function.
Integer. Degrees of freedom for seasonality. Defaults to 8.