Reads in data and geography names for analysis from a CSV file.
hc_read_data(
input_csv_path,
dependent_col,
date_col,
region_col,
temperature_col,
population_col
)'df_list'. A list of dataframes for each geography with formatted and renamed columns.
Path to a CSV containing a daily time series of health outcome and climate data per geography.
Character. Name of the column in the dataframe containing the dependent health outcome variable e.g. deaths.
Character. Name of the column in the dataframe containing the date.
Character. Name of the column in the dataframe that contains the geography name(s).
Character. Name of the column in the dataframe that contains the temperature column.
Character. Name of the column in the dataframe that contains the population estimate per geography.