Produces cumulative relative risk and confidence intervals from analysis.
hc_rr_results(
pred_list,
df_list,
minpercgeog_,
attr_thr_high = 97.5,
attr_thr_low = 2.5
)'rr_results'. Dataframe containing cumulative relative risk and confidence intervals from analysis.
A list containing predictions from the model by geography.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular geography.
Vector. Percentile of minimum mortality temperature for each geography.
Integer. Percentile at which to define the upper temperature threshold for calculating attributable risk. Defaults to 97.5.
Integer. Percentile at which to define the lower temperature threshold for calculating attributable risk. Defaults to 2.5.