Saves a CSV file of cumulative relative risk and confidence intervals.
hc_save_results(
rr_results,
res_attr_tot,
attr_yr_list,
attr_mth_list,
power_list_high,
power_list_low,
output_folder_path = NULL
)Dataframe containing cumulative relative risk and confidence intervals from analysis.
Matrix containing total attributable fractions, numbers and rates for each geography over the whole time series.
A list of matrices containing yearly estimates of attributable fractions, numbers and rates by geography.
A list of data frames containing total attributable fractions, numbers and rates by calendar month and geography.
Path to folder where results should be saved. Defaults to NULL.