Aggregates PM2.5 data to monthly averages by region and joins it with attributable risk data using year, month, and region as keys.
join_ar_and_pm_monthly(pm_data, an_ar_data)A data frame with monthly average PM2.5 values joined to attributable risk data.
A data frame with columns: year, month, region, mean_PM. Represents monthly PM2.5 estimates.
A data frame with columns: year, month, region. Represents attributable risk or fraction data to be joined with PM2.5 estimates.