Read in a csv file containing a monthly time series of health outcomes and population data. Renames columns and creates time variables for spatiotemporal analysis.
load_and_process_data(
health_data_path,
region_col,
district_col,
date_col = NULL,
year_col = NULL,
month_col = NULL,
case_col,
case_type,
tot_pop_col
)A dataframe with formatted and renamed columns.
Path to a csv file containing a monthly time series of data for health outcome case type, which may be disaggregated by sex (under five case or above five case), and by Region and District.
Character. Name of the column in the dataframe that contains the region names.
Character. Name of the column in the dataframe that contains the district names.
Character. Name of the column in the dataframe that contains the date. Defaults to NULL.
Character. Name of the column in the dataframe that contains the year.
Character. Name of the column in the dataframe that contains the month.
Character. Name of the column in the dataframe that contains the disease cases to be considered.
Character. The type of disease that the case column refers to. Must be one of 'diarrhea' or 'malaria'.
Character. Name of the column in the dataframe that contains the total population.