Loads a dataframe containing a daily time series of health and climate data, which may be disaggregated by region.
load_wildfire_data(
health_path,
ncdf_path,
shp_path,
join_wildfire_data = TRUE,
date_col,
region_col,
shape_region_col = NULL,
mean_temperature_col,
health_outcome_col,
population_col = NULL,
rh_col = NULL,
wind_speed_col = NULL,
pm_2_5_col = NULL
)Dataframe containing a daily time series of climate and health data.
Path to a CSV file containing a daily time series of data for a particular health outcome, which may be disaggregated by region. If this does not include a column with wildfire-related PM2.5, use join_wildfire_data = TRUE to join these data.
Path to a NetCDF file containing a daily time series of gridded wildfire-related PM2.5 concentration data.
Path to a shapefile .shp of the geographical boundaries for which to extract mean values of wildfire-related PM2.5
Boolean. If TRUE, a daily time series of wildfire-related PM2.5 concentration is joined to the health data. If FALSE, the data set is loaded without any additional joins.
Character. Name of the column in the dataframe that contains the date.
Character. Name of the column in the dataframe that contains the region names.
Character. Name of the column in the shapefile dataframe that contains the region names.
Character. Name of the column in the dataframe that contains the mean temperature column.
Character. Name of the column in the dataframe that contains the health outcome count column (e.g. number of deaths, hospital admissions)
Character. Name of the column in the dataframe that
contains the population data. Defaults to NULL. If omitted, a pop column
is used when present.
Character. Name of the column in the dataframe that contains daily relative humidity values.Defaults to NULL.
Character. Name of the column in the dataframe that contains the daily windspeed values.Defaults to NULL.
Character. The name of the column containing PM2.5 values in micrograms. This is only required if health data isn't joined. Defaults to NULL.