Estimate attributable numbers for each region and confidence intervals using Monte Carlo simulations.
mh_attr(df_list, cb_list, pred_list, minpercreg, attr_thr = 97.5)A list containing attributable numbers per region
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
A list of cross-basis matrices by region.
A list containing predictions from the model by region.
Vector. Percentile of maximum suicide temperature for each region.
Integer. Percentile at which to define the temperature threshold for calculating attributable risk. Defaults to 97.5.