Produces results on QAIC for each model combination, variance inflation factor for each independent variable, and plots for residuals to assess the models
mh_model_validation(
df_list,
cb_list,
independent_cols = NULL,
save_fig = FALSE,
save_csv = FALSE,
output_folder_path = NULL,
seed = NULL
)qaic_results A dataframe of QAIC and dispersion metrics for each model combination and geography.
qaic_summary A dataframe with the mean QAIC and dispersion metrics for each model combination.
vif_results A dataframe. Variance inflation factors for each independent variables by region.
vif_summary A dataframe with the mean variance inflation factors for each independent variable.
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
List of cross_basis matrices from create_crossbasis function.
Additional independent variables to test in model validation as confounders.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Boolean. Whether to save the results as a CSV. Defaults to FALSE.
Path to folder where plots should be saved. Defaults to NULL.