Plots the power statistic for each reference temperature at and above the attributable risk threshold for each area.
mh_plot_power(
power_list,
save_fig = FALSE,
output_folder_path = NULL,
country = "National"
)Plots of power by temperature for the attributable threshold and above for each area.
A list containing power information by area.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Path to folder where plots should be saved. Defaults to NULL.
Character. Name of country for national level estimates. Defaults to 'National'