Plots cumulative lag exposure-response function with histogram of temperature distribution for each region
mh_plot_rr(
df_list,
pred_list,
attr_thr = 97.5,
minpercreg,
country = "National",
save_fig = FALSE,
output_folder_path = NULL
)Plots of cumulative lag exposure-response function with histogram of temperature distribution for each region
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
A list containing predictions from the model by region.
Integer. Percentile at which to define the temperature threshold for calculating attributable risk. Defaults to 97.5.
Vector. Percentile of minimum suicide temperature for each area.
Character. Name of country for national level estimates. Defaults to 'National'.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Path to folder where plots should be saved. Defaults to NULL.