Use model to run regional predictions
mh_predict_reg(
df_list,
var_fun = "bs",
var_per = c(25, 50, 75),
var_degree = 2,
minpercreg,
blup,
coef_,
vcov_,
meta_analysis = FALSE
)A list containing predictions by region
A list of dataframes containing daily timeseries data for a health outcome and climate variables which may be disaggregated by a particular region.
Character. Exposure function for argvar (see dlnm::crossbasis). Defaults to 'bs'.
Vector. Internal knot positions for argvar (see dlnm::crossbasis). Defaults to c(25,50,75).
Integer. Degree of the piecewise polynomial for argvar (see dlnm::crossbasis). Defaults to 2 (quadratic).
Vector. Percentile of maximum suicide temperature for each region.
A list. BLUP (best linear unbiased predictions) from the meta-analysis model for each region.
A matrix of coefficients for the reduced model.
A list. Covariance matrices for each region for the reduced model.
Boolean. Whether to perform a meta-analysis.