Reads in a CSV file for a daily time series of health and climate data, renames columns and creates stratum for case-crossover analysis.
mh_read_and_format_data(
data_path,
date_col,
region_col = NULL,
temperature_col,
health_outcome_col,
population_col
)A list of dataframes with formatted and renamed columns.
Path to a csv file containing a daily time series of data for a particular health outcome and climate variables, which may be disaggregated by region.
Character. Name of the column in the dataframe that contains the date.
Character. Name of the column in the dataframe that contains the region names. Defaults to NULL.
Character. Name of the column in the dataframe that contains the temperature column.
Character. Name of the column in the dataframe that contains the health outcome count column (e.g. number of deaths, hospital admissions).
Character. Name of the column in the dataframe that contains the population estimate coloumn.