Saves a CSV file of cumulative relative risk and confidence intervals.
mh_save_results(
rr_results,
res_attr_tot,
attr_yr_list,
attr_mth_list,
power_list,
output_folder_path = NULL
)Dataframe containing cumulative relative risk and confidence intervals from analysis.
Matrix containing total attributable fractions, numbers and rates for each area over the whole time series.
A list of matrices containing yearly estimates of attributable fractions, numbers and rates by area
A list of data frames containing total attributable fractions, numbers and rates by calendar month and area.
A list containing power information by area.
Path to folder where results should be saved. Defaults to NULL.