Plots relative risk and confidence intervals for each lag value of wildfire-related PM2.5.
plot_RR_core(
rr_data,
save_fig = FALSE,
wildfire_lag,
output_folder_path = NULL,
region_name = "All regions",
ylims = NULL
)Plot of relative risk and confidence intervals for each lag of wildfire-related PM2.5.
Dataframe of relative risk and confidence intervals for each lag of wildfire-related PM2.5.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Integer. The maximum number of days for which to plot the lags for wildfire PM2.5. Defaults to 3.
Path to folder where plots should be saved. Defaults to NULL.
Character. The name of the region. Defaults to 'All regions'.