Aggregates annual average attributable fraction estimates and generates a ggplot showing the central estimate and CI.
plot_aggregated_AF_core(data, region_name = NULL)A ggplot object showing annual attributable rates with confidence intervals.
A data frame with columns: year, average_attributable_fraction, lower_ci_attributable_fraction, and upper_ci_attributable_fraction.
Optional character string used to label the plot title with a region name. Defaults to NULL.