Aggregates wildfire smoke-related PM2.5 attributable numbers by region and creates a bar plot showing the total attributable number of deaths per region.
plot_an_by_region(data, output_dir = ".")A ggplot object representing the bar plot.
A data frame containing columns:
region: Region names.
total_attributable_number: Numeric values of attributable numbers.
A character string specifying the directory where the plot will be saved.
Defaults to the current working directory (".").