Plot a grid of box plots for multiple numeric variables
plot_boxplots(
df,
columns = NULL,
select_numeric = FALSE,
title = "Boxplots",
ylabs = NULL,
save_plot = FALSE,
output_path = NULL
)The dataframe containing the data
A character vector of numeric column names to plot
If TRUE, all numeric columns in df will be selected for plotting.
The overall title for the plot
A character vector of y-axis labels (e.g., with units) corresponding to the columns.
Whether to save the plot as a PDF
The file path to save the PDF (if save_plot is TRUE)