Generates and saves a plot of monthly random effects for different regions, visualizing their contribution to Malaria Incidence Rate.
plot_monthly_random_effects(
combined_data,
model,
save_fig = FALSE,
output_dir = NULL
)THe monthly random effects plot.
Data list from combine_health_climate_data() function.
The fitted model object.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Character. The path to save the visualisation to. Defaults to NULL.