Plot the rate of a dependent variable per 100,000 population per year.
plot_rate_overall(
df,
dependent_col,
population_col,
date_col,
title,
save_rate = FALSE,
output_path = NULL
)The dataframe containing the data.
The name of the column representing the dependent variable.
The name of the column representing the population.
The name of the column containing date values.
Character. The specific title for the subset of data being used.
Whether to save the plot as a PDF.
The file path to save the plot if save_rate is TRUE.