Plots the relative risk of Malaria cases by the maximum temperature and cumulative rainfall at country, Region and District level
plot_relative_risk(
data,
model,
param_term,
max_lag,
nk,
level,
case_type,
filter_year = NULL,
output_dir = NULL,
save_csv = FALSE,
save_fig = FALSE
)Relative risk plot at country, region, and district levels.
Data list from combine_health_climate_data() function.
The fitted model from run_inla_models() function.
A character vector or list containing parameter terms such
as tmax (temperature exposure) and rainfall (rainfall exposure).
Default to tmax.
A character vector specifying the geographical disaggregation.
Can take one of the following values: country, region, or district.
Default to country.
Character. The type of disease that the case column refers
to. Must be one of "diarrhea" or "malaria".
Integer. The year to filter to data to. This gives the possibility to user to have the plot for a specific year. When Defaults to NULL, it provides the plot by grouping all the years in the dataset.
Character. The path where the PDF file will be saved. Default to NULL.
Boolean. If TRUE, saves the RR data to the specified directory. Defaults to FALSE.
Boolean. If TRUE, saves the plot to the specified directory. Defaults to FALSE.