Generates a ggplot showing relative risk estimates and confidence intervals across PM2.5 levels for a given region.
plot_rr_by_pm_core(data, region_name = "All Regions", ylims = c(-2, 2))A ggplot object showing relative risk and CI.
A data frame with columns: pm_levels, relative_risk, ci_lower, and ci_upper.
Optional character string used to label the plot title with a region name. Defaults to "All Regions".
Numeric vector of length 2 specifying y-axis limits. Defaults to c(-2, 2).