Generates a map of the relative risk of the diseases cases associated with climate hazards, including extreme temperature and cumulative rainfall, at a specified geographical level (district or region).
plot_rr_map(
combined_data,
model,
param_term = "tmax",
max_lag,
nk,
level = "district",
case_type,
filter_year = NULL,
output_dir = NULL,
save_fig = FALSE,
save_csv = FALSE,
cumulative = FALSE
)Relative risk map at the chosen level.
A list returned from the combine_health_climate_data()
function. This list should include both the health-climate data and the map data.
The fitted model object returned from the run_inla_models() function.
A character vector or list specifying the climate parameters
(e.g., tmax for maximum temperature, rainfall for precipitation) to
include in the map. Defaults to tmax.
A character string indicating the spatial aggregation level.
Options are region or district. Defaults to district.
Character. The type of disease that the case column refers
to. Must be one of diarrhea or malaria.
Integer. The year to filter to data to. Defaults to NULL.
Character. The directory path where the output PDF file should be saved. Defaults to NULL.
Boolean. If TRUE, saves the plot to the specified directory. Defaults to FALSE.
Boolean. If TRUE, plot and save cumulative risk of all year for the specific exposure at region and district level. Defaults to FALSE.