Plot a grid of scatter graphs comparing one column to various others.
plot_scatter_grid(
df,
main_col,
comparison_cols,
title,
save_scatters = FALSE,
output_path = "",
units = NULL
)The dataframe containing the raw data.
The main column to compare with all other columns.
The columns to compare with.
The title of your plot.
Whether or not to save the plot.
The path to output the plot to.
A named character vector of units for each variable.