Plot the total of selected variables per year.
plot_total_variables_by_year(
df,
date_col,
variables,
title,
save_total = FALSE,
output_path = ""
)Plots are printed to the console or saved as PDF files.
A dataframe containing the data.
The name of the column containing date values.
Column names to be summed and plotted.
Character. The specific title for the subset of data being used.
if TRUE, saves each plot as a PDF.
The file path for saving plots.