Generates and saves plots of yearly spatial random effect of the diseases incidence rate at district level.
plot_yearly_spatial_random_effect(
combined_data,
model,
case_type,
save_fig = FALSE,
output_dir = NULL
)The yearly space random effect for the disease incidence rate plot.
Data list from combine_health_climate_data() function.
The fitted model from run_inla_models() function.
Character. The type of disease that the case column refers
to. Must be one of diarrhea or malaria.
Boolean. Whether to save the plot as an output. Defaults to FALSE.
Character. The path to save the fitted model results to. Defaults to NULL.