prepare_descriptive_output_dir: Validate and prepare base output directory for descriptive stats.
Description
Validate and prepare base output directory for descriptive stats.
Usage
prepare_descriptive_output_dir(output_path, create_base_dir = FALSE)
Value
Character. Validated output path.
Arguments
- output_path
Character. Base output path.
- create_base_dir
Logical. Whether to create a missing base directory.