powered by
Read a csv file into memory as a data frame.
read_input_data(input_csv_path)
A dataframe containing the data from the csv.
The path to the csv to read as a dataframe.
input_csv_path <- "directory/file_name.csv"
Run the code above in your browser using DataLab