Take a dataframe, and apply various different cleaning methods to it in order to prepare the data for use with a climate indicator.
reformat_data(df, reformat_date = TRUE, fill_na = c(), year_from_date = TRUE)The cleaned/reformatted data frame.
The dataframe to apply cleaning/reformatting to.
Whether or not to reformat the data to the Date datatype.
A vector of column names to fill NA values in (fills with 0).
Derive a new column 'year' from the date column.