: Create and run multiple INLA (Integrated Nested Laplace Approximation) models to the dataset, evaluates them using DIC (Deviance Information Criterion), and identifies the best-fitting model.
run_inla_models(
combined_data,
basis_matrices_choices,
inla_param,
max_lag,
nk,
case_type,
output_dir = NULL,
save_model = FALSE,
family = "nbinomial",
config = FALSE
)A list containing the model, baseline_model, and the dic_table.
A dataframe resulting from combine_health_climate_data() function.
A character vector specifying the basis matrix
parameters to be included in the model. Possible values are tmax, and rainfall.
A character vector specifying the confounding exposures to
be included in the model. Possible values are tmax,tmin, rainfall,
r_humidity, runoff, ndvi, Etc.
Character. The type of disease that the case column refers
to. Must be one of diarrhea or malaria.
Character. The path to save model output to. Defaults to NULL.
Boolean. Whether to save the results as a CSV. Defaults to FALSE.
Character. The probability distribution for the response
variable. The user may also have the possibility to choose nbinomial for a
negative binomial distribution. Defaults topoisson.
Boolean. Enable additional model configurations. Defaults to FALSE.