Saves a CSV file of relative risk and confidence intervals for each lag value of wildfire-related PM2.5. Also optionally save results of attributable numbers/fractions.
save_wildfire_results(
rr_results,
an_ar_results = NULL,
annual_af_an_results = NULL,
output_folder_path
)Dataframe of relative risk and confidence intervals for each lag of wildfire-related PM2.5.
Dataframe containing attributable number/fraction results. Defaults to NULL.
Path to folder where results should be saved.