Adds columns for strata for each region:year:month:dayofweek and for the total counts of a health outcome across days in each stratum.
time_stratify(data)Dataframe with additional columns for stratum (region:year:month:dayofweek) and for the total counts of a health outcome across days in each stratum.
Dataframe containing a daily time series of climate and health data. Assumes that 'data' has a 'month', 'year', 'dow' and 'region' column.